abacusai.mcp_config — AbacusAI documentation

# abacusai.mcp_config

## Classes

`McpConfig` | Model Context Protocol Config

## Module Contents

class abacusai.mcp_config.McpConfig(client, mcpConfig=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Model Context Protocol Config

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - mcpConfig (dict) – The MCP configuration for the current user

  mcp_config = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict